From 830d119fa8635545560fc3aedb2c1da8492755cc Mon Sep 17 00:00:00 2001
From: ftimme <ft@falkotimme.com>
Date: Thu, 02 Apr 2009 09:42:59 -0400
Subject: [PATCH] - Added AAAA records to the DNS-Manager.

---
 interface/web/help/support_message_edit.php |    7 ++-----
 1 files changed, 2 insertions(+), 5 deletions(-)

diff --git a/interface/web/help/support_message_edit.php b/interface/web/help/support_message_edit.php
index a36b5db..bef1e9b 100644
--- a/interface/web/help/support_message_edit.php
+++ b/interface/web/help/support_message_edit.php
@@ -7,11 +7,8 @@
 require_once('../../lib/config.inc.php');
 require_once('../../lib/app.inc.php');
 
-//* Checking module permissions
-if(!stristr($_SESSION['s']['user']['modules'],'help')) {
-	header("Location: ../index.php");
-	exit;
-}
+//* Check permissions for module
+$app->auth->check_module_permissions('help');
 
 //* Loading the templating and form classes
 $app->uses('tpl,tform,tform_actions');

--
Gitblit v1.9.1